@@ -6,7 +6,7 @@ from .selection import select
 from .transform import Combiner
 from .metrics import KS, F1, PSI
 from .plot import bin_plot,score_plot
-from .model import Model
+# from .model import Model
 from .performance import performance
 from .version import __version__
 
