@@ -10,7 +10,7 @@ import numpy as np
 import glob
 import math
 import xgboost as xgb
-
+from lapras.model import Model
 
 
 import lapras
@@ -47,9 +47,9 @@ c.fit(train_selected, y = 'bad', method = 'dt', min_samples = 0.05,n_bins=5)
 # print(c.transform(train_selected, labels=True).iloc[0:10, :])
 
 cols = train_selected.columns
-for col in cols:
-    if col != 'bad':
-        lapras.bin_plot(c.transform(train_selected[[col,'bad']], labels=True), col=col, target='bad')
+# for col in cols:
+#     if col != 'bad':
+#         lapras.bin_plot(c.transform(train_selected[[col,'bad']], labels=True), col=col, target='bad')
 
 
 
@@ -67,7 +67,7 @@ final_data = train_woe
 
 
 # 评分卡建模
-model = lapras.Model()
+model = Model()
 model.fit(final_data.drop(['bad'],axis=1), final_data['bad'])
 pred_train = model.predict(final_data.drop(['bad'],axis=1))
 result = model.export(final_data.drop(['bad'],axis=1))
